// Copyright (c) 1999-2002 David Muse
// See the COPYING file for more information.

// for struct timespec (it includes inttypes.h as well)
#include <rudiments/private/snoozeincludes.h>

#include <sys/types.h>

struct sembuf;
union semun;
